Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DDL ¶
type DDL struct {
Schema string `json:"$schema"`
Metadata Metadata `json:"metadata"`
Query *common.InputItem `json:"query"`
Output map[string]*common.OutputItem `json:"output"`
SourceLocation string `json:"-"`
sync.Mutex
}
func (*DDL) RenderConsole ¶ added in v0.22.0
RenderConsole create console appropriate output for data provider ddls
func (*DDL) RenderMarkdown ¶ added in v0.22.0
RenderMarkdown create markdown appropriate output for data provider ddls
type FuncMap ¶
type FuncMap map[string]FuncMapEntry
type FuncMapEntry ¶
type Metadata ¶
type Metadata struct {
License string `json:"license"`
Author string `json:"author"`
Timeout int `json:"timeout"`
Name string `json:"name"`
Version string `json:"version"`
URL string `json:"url"`
Description string `json:"description"`
Provider string `json:"provider,omitempty"`
}
Metadata describes an agent at a high level and is required for any agent
Click to show internal directories.
Click to hide internal directories.